@@ -138,32 +138,60 @@ int main
 
 		// testing S2K functions
 		tmcg_openpgp_byte_t octcnt = 1;
-		size_t hashcnt = (16 + (octcnt & 15)) << ((octcnt >> 4) + 6);
+		size_t hashcnt = ((uint32_t)16 + (octcnt & 15)) << ((octcnt >> 4) + 6);
 		size_t keylen = gcry_cipher_get_algo_keylen(TMCG_GCRY_ENC_ALGO);
 		tmcg_openpgp_secure_string_t keystr = "Test";
-		char salt[8];
-		char key[keylen];
-		gcry_error_t err;
-		gcry_create_nonce(salt, sizeof(salt));
-		std::cout << "gcry_kdf_derive(..., GCRY_KDF_ITERSALTED_S2K, " <<
-			"TMCG_GCRY_MD_ALGO, ..., " << hashcnt << ", ...)" << std::endl;
-		err = gcry_kdf_derive(keystr.c_str(), keystr.length(),
-			GCRY_KDF_ITERSALTED_S2K, TMCG_GCRY_MD_ALGO, salt, sizeof(salt),
-			hashcnt, sizeof(key), key);
-		assert(!err);
-		tmcg_openpgp_octets_t salt2;
-		tmcg_openpgp_secure_octets_t outs2;
-		outs.clear();
-		for (size_t i = 0; i < sizeof(key); i++)
-			outs.push_back(key[i]); // copy the result
-		for (size_t i = 0; i < sizeof(salt); i++)
-			salt2.push_back(salt[i]); // copy the salt
-		std::cout << "S2KCompute(...)" << std::endl;
-		CallasDonnerhackeFinneyShawThayerRFC4880::
-			S2KCompute(TMCG_OPENPGP_HASHALGO_SHA256, keylen, keystr, salt2, true,
-			octcnt, outs2);
-		assert(CallasDonnerhackeFinneyShawThayerRFC4880::
-			OctetsCompareConstantTime(outs, outs2));
+		for (size_t i = 0; i < 42; i++)
+		{
+			char key[keylen];
+			gcry_error_t err;
+			std::cout << "gcry_kdf_derive(..., GCRY_KDF_SIMPLE_S2K, " <<
+				"TMCG_GCRY_MD_ALGO, ..., " << hashcnt << ", ...)" << std::endl;
+			err = gcry_kdf_derive(keystr.c_str(), keystr.length(),
+				GCRY_KDF_SIMPLE_S2K, TMCG_GCRY_MD_ALGO, NULL, 0,
+				hashcnt, sizeof(key), key);
+			assert(!err);
+			outs.clear();
+			for (size_t i = 0; i < sizeof(key); i++)
+				outs.push_back(key[i]); // copy the result
+			std::cout << "S2KCompute(..., false, ...)" << std::endl;
+			tmcg_openpgp_octets_t salt2;
+			tmcg_openpgp_secure_octets_t outs2;
+			CallasDonnerhackeFinneyShawThayerRFC4880::
+				S2KCompute(TMCG_OPENPGP_HASHALGO_SHA256, keylen, keystr, salt2,
+				false, octcnt, outs2);
+			assert(CallasDonnerhackeFinneyShawThayerRFC4880::
+				OctetsCompareConstantTime(outs, outs2));
+			keylen++; // increase length of the derived key during tests
+		}
+		keylen = gcry_cipher_get_algo_keylen(TMCG_GCRY_ENC_ALGO); // reset
+		for (size_t i = 0; i < 42; i++)
+		{
+			char salt[8];
+			char key[keylen];
+			gcry_error_t err;
+			gcry_create_nonce(salt, sizeof(salt));
+			std::cout << "gcry_kdf_derive(..., GCRY_KDF_ITERSALTED_S2K, " <<
+				"TMCG_GCRY_MD_ALGO, ..., " << hashcnt << ", ...)" << std::endl;
+			err = gcry_kdf_derive(keystr.c_str(), keystr.length(),
+				GCRY_KDF_ITERSALTED_S2K, TMCG_GCRY_MD_ALGO, salt, sizeof(salt),
+				hashcnt, sizeof(key), key);
+			assert(!err);
+			tmcg_openpgp_octets_t salt2;
+			tmcg_openpgp_secure_octets_t outs2;
+			outs.clear();
+			for (size_t i = 0; i < sizeof(key); i++)
+				outs.push_back(key[i]); // copy the result
+			for (size_t i = 0; i < sizeof(salt); i++)
+				salt2.push_back(salt[i]); // copy the salt
+			std::cout << "S2KCompute(..., true, ...)" << std::endl;
+			CallasDonnerhackeFinneyShawThayerRFC4880::
+				S2KCompute(TMCG_OPENPGP_HASHALGO_SHA256, keylen, keystr, salt2,
+				true, octcnt, outs2);
+			assert(CallasDonnerhackeFinneyShawThayerRFC4880::
+				OctetsCompareConstantTime(outs, outs2));
+			keylen++; // increase length of the derived key during tests
+		}
 
 		// create different asymmetric keys by using libgcrypt
 		size_t erroff = 0;
@@ -558,13 +586,13 @@ int main
 		parse_ok = primary->CheckSubkeys(ring, 3);
 		assert(parse_ok);
 		std::string fpr, kid;
-		std::cout << "FingerprintCompute()" << std::endl;
+		std::cout << "FingerprintConvertPlain()" << std::endl;
 		CallasDonnerhackeFinneyShawThayerRFC4880::
-			FingerprintCompute(primary->pub_hashing, fpr);
+			FingerprintConvertPlain(primary->fingerprint, fpr);
 		std::cout << fpr << std::endl;
-		std::cout << "KeyidCompute()" << std::endl;
+		std::cout << "KeyidConvert()" << std::endl;
 		CallasDonnerhackeFinneyShawThayerRFC4880::
-			KeyidCompute(primary->pub_hashing, kid);
+			KeyidConvert(primary->id, kid);
 		std::cout << kid << std::endl;
 		std::cout << "!primary->Weak()" << std::endl;
 		bool check_ok = primary->Weak(3);
@@ -848,6 +876,47 @@ int main
 		}
 		delete mallory;
 		delete ring;
+
+		// test a non-encrypted V5 key provided by Werner Koch
+		std::string emma_armored =
+"-----BEGIN PGP PRIVATE KEY BLOCK-----\r\n\r\n"
+"lGEFXJH05BYAAAAtCSsGAQQB2kcPAQEHQFhZlVcVVtwf+21xNQPX+ecMJJBL0MPd\r\n"
+"fj75iux+my8QAAAAAAAiAQCHZ1SnSUmWqxEsoI6facIVZQu6mph3cBFzzTvcm5lA\r\n"
+"Ng5ctBhlbW1hLmdvbGRtYW5AZXhhbXBsZS5uZXSIlgUTFggASCIhBRk0e8mHJGQC\r\n"
+"X5nfPsLgAA7ZiEiS4fez6kyUAJFZVptUBQJckfTkAhsDBQsJCAcCAyICAQYVCgkI\r\n"
+"CwIEFgIDAQIeBwIXgAAA9cAA/jiR3yMsZMeEQ40u6uzEoXa6UXeV/S3wwJAXRJy9\r\n"
+"M8s0AP9vuL/7AyTfFXwwzSjDnYmzS0qAhbLDQ643N+MXGBJ2BZxmBVyR9OQSAAAA\r\n"
+"MgorBgEEAZdVAQUBAQdA+nysrzml2UCweAqtpDuncSPlvrcBWKU0yfU0YvYWWAoD\r\n"
+"AQgHAAAAAAAiAP9OdAPppjU1WwpqjIItkxr+VPQRT8Zm/Riw7U3F6v3OiBFHiHoF\r\n"
+"GBYIACwiIQUZNHvJhyRkAl+Z3z7C4AAO2YhIkuH3s+pMlACRWVabVAUCXJH05AIb\r\n"
+"DAAAOSQBAP4BOOIR/sGLNMOfeb5fPs/02QMieoiSjIBnijhob2U5AQC+RtOHCHx7\r\n"
+"TcIYl5/Uyoi+FOvPLcNw4hOv2nwUzSSVAw==\r\n"
+"=IiS2\r\n"
+"-----END PGP PRIVATE KEY BLOCK-----\r\n";
+		TMCG_OpenPGP_Prvkey *emma = NULL;
+		ring = new TMCG_OpenPGP_Keyring();
+		std::cout << "PrivateKeyBlockParse(emma_armored, 3, \"\", emma)" <<
+			std::endl;
+		parse_ok = CallasDonnerhackeFinneyShawThayerRFC4880::
+			PrivateKeyBlockParse(emma_armored, 3, "", emma);
+		assert(parse_ok);
+		if (gcry_check_version("1.7.0"))
+		{
+			TMCG_OpenPGP_Pubkey *emmapub = emma->pub; // get the public key 
+			emma->RelinkPublicSubkeys(); // relink the contained subkeys
+			std::cout << "CheckSelfSignatures()" << std::endl;
+			parse_ok = emmapub->CheckSelfSignatures(ring, 3);
+			assert(parse_ok);
+			std::cout << "CheckSubkeys()" << std::endl;
+			parse_ok = emmapub->CheckSubkeys(ring, 3);
+			assert(parse_ok);
+			std::cout << "!primary->Weak()" << std::endl;
+			check_ok = emmapub->Weak(3);
+			assert(!check_ok);
+			emma->RelinkPrivateSubkeys(); // undo the relinking
+		}
+		delete emma;
+		delete ring;
 	
 		return 0;
 	}
